@@ -9,7 +9,7 @@ use Digest::SHA();
 use WebService::HIBP::Breach();
 use WebService::HIBP::Paste();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub _LENGTH_OF_PASSWORD_PREFIX { return 5; }
 
@@ -154,7 +154,7 @@ WebService::HIBP - An interface to the Have I Been Pwned webservice at haveibeen
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -210,7 +210,7 @@ It returns the count of how many times it appears in the data set or "0" if it d
 
 =head2 account
 
-The most common use of the API is to return a list of all breaches a particular account has been involved in. The API takes a single parameter which is the account to be searched for. The account is not case sensitive and will be trimmed of leading or trailing white spaces.
+The most common use of the API is to return a list of all breaches a particular account has been involved in. The API takes a single parameter which is the account to be searched for. The account is not case sensitive and will be trimmed of leading or trailing white spaces.  Returns a list of L<breaches|WebService::HIBP::Breach>.
 
 Parameters:
 
@@ -228,13 +228,20 @@ Parameters:
 	use v5.10;
 
     my $hibp = WebService::HIBP->new();
-    foreach my $breach ( $hibp->account('test@example.com', domain => 'adobe.com' ) ) {
+    foreach my $breach ( $hibp->account( 'test@example.com', domain => 'adobe.com' ) ) {
 	   say $breach->name();
 	}
 
 =head2 breach
 
-Sometimes just a single L<breach|WebService::HIBP::Breach> is required and this can be retrieved by the breach L<name|WebService::HIBP::Breach#name>. This is the stable value which may or may not be the same as the breach L<title|WebService::HIBP::Breach#title> (which can change).
+Sometimes just a single L<breach|WebService::HIBP::Breach> is required and this can be retrieved by the breach L<name|WebService::HIBP::Breach#name>. This is the stable value which may or may not be the same as the breach L<title|WebService::HIBP::Breach#title> (which can change). Returns a list of L<breaches|WebService::HIBP::Breach>.
+
+    use WebService::HIBP();
+	use v5.10;
+
+    my $hibp = WebService::HIBP->new();
+    my $breach = $hibp->breach( 'Adobe' ) ) {
+	say $breach->title();
 
 =head2 breaches
 
@@ -244,17 +251,42 @@ Parameters:
 
 =over 4
 
-=item * domain - Filters the result set to only breaches against the domain specified. It is possible that one site (and consequently domain), is compromised on multiple occasions. 
+=item * domain - Filters the result set to only breaches against the domain specified. It is possible that one site (and consequently domain), is compromised on multiple occasions.  Returns a list of L<breaches|WebService::HIBP::Breach>.
+
 
 =back 
 
+    use WebService::HIBP();
+	use v5.10;
+
+    my $hibp = WebService::HIBP->new();
+    foreach my $breach ( $hibp->breaches( domain => 'adobe.com' ) ) {
+	   say $breach->name();
+	}
+
 =head2 data_classes
 
 A "data class" is an attribute of a record compromised in a breach. For example, many breaches expose data classes such as "Email addresses" and "Passwords". The values returned by this service are ordered alphabetically in a string array and will expand over time as new breaches expose previously unseen classes of data.
 
+    use WebService::HIBP();
+	use v5.10;
+
+    my $hibp = WebService::HIBP->new();
+    foreach my $class ( $hibp->data_classes() ) {
+	   say $class;
+	}
+
 =head2 pastes
 
-This method takes a single parameter which is the email address to be searched for. Unlike searching for breaches, usernames that are not email addresses cannot be searched for. The email is not case sensitive and will be trimmed of leading or trailing white spaces.
+This method takes a single parameter which is the email address to be searched for. Unlike searching for breaches, usernames that are not email addresses cannot be searched for. The email is not case sensitive and will be trimmed of leading or trailing white spaces.  Returns a list of L<pastes|WebService::HIBP::Paste>.
+
+    use WebService::HIBP();
+	use v5.10;
+
+    my $hibp = WebService::HIBP->new();
+    foreach my $paste ( $hibp->pastes( 'test@example.com' ) ) {
+	   say $paste->source();
+	}
 
 =head1 DIAGNOSTICS
 
