@@ -3,7 +3,7 @@ package WebService::HIBP::Paste;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my ( $class, %parameters ) = @_;
@@ -53,7 +53,7 @@ WebService::HIBP::Paste - An instance of a paste from the Have I Been Pwned webs
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -64,7 +64,7 @@ Check the security of your accounts/email addresses and passwords
 
     my $hibp = WebService::HIBP->new();
     foreach my $paste ($hibp->pastes()) {
-       say $breach->description();
+       say $paste->source();
     }
 
 =head1 DESCRIPTION
